@@ -3,7 +3,7 @@
 # Author: v.stone@163.com
 
 
-from qixinApi import qxapi
+from .qxapi import Sdk
 
 
 if __name__ == '__main__':
